Tracker class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compare({required AsyncFunction asyncCallback, String? asyncName, required SyncFunction syncCallback, String? syncName}) Future<void>
Compares the time it takes for an asynchronous callback and a synchronous callback to complete.
compareAsync(AsyncFunction first, AsyncFunction second, {String? firstName, String? secondName}) Future<void>
Compares the time it takes for two asynchronous callbacks to complete.
compareSync(SyncFunction first, SyncFunction second, {String? firstName, String? secondName}) → void
Compares the time it takes for two synchronous callbacks to complete.
trackAsync(AsyncFunction callback, {String? name}) Future<Duration>
Tracks the time it takes for an asynchronous callback to complete.
trackSync(SyncFunction callback, {String? name}) Duration
Tracks the time it takes for a synchronous callback to complete.